@@ -1,4 +1,3 @@
-#![allow(missing_docs)]
 pub(crate) mod object;
 pub use object::ObjectAccessExt;
 
@@ -7,3 +6,6 @@ pub use reference::ReferenceAccessExt;
 
 mod repository;
 pub use repository::RepositoryAccessExt;
+
+mod cache;
+pub use cache::CacheAccessExt;
