@@ -1,3 +1,4 @@
+use git_hash::ObjectId;
 use git_object::{bstr::BStr, TreeRefIter};
 
 use crate::{
@@ -9,7 +10,23 @@ impl<'repo, A> TreeRef<'repo, A>
 where
     A: easy::Access + Sized,
 {
+    /// Obtain a tree instance by handing in all components that it is made up of.
+    pub fn from_id_and_data(id: impl Into<ObjectId>, data: std::cell::Ref<'repo, [u8]>, access: &'repo A) -> Self {
+        TreeRef {
+            id: id.into(),
+            data,
+            access,
+        }
+    }
     // TODO: move implementation to git-object, tests.
+    /// Follow a sequence of `path` components starting from this instance, and look them up one by one until the last component
+    /// is looked up and its tree entry is returned.
+    ///
+    /// # Performance Notes
+    ///
+    /// Searching tree entries is currently done in sequence, which allows to the search to be allocation free. It would be possible
+    /// to re-use a vector and use a binary search instead, which might be able to improve performance over all.
+    /// However, a benchmark should be created first to have some data and see which trade-off to choose here.
     pub fn lookup_path<I, P>(mut self, path: I) -> Result<Option<git_object::tree::Entry>, find::existing::Error>
     where
         I: IntoIterator<Item = P>,
