@@ -1,5 +1,5 @@
-#![allow(missing_docs)]
-use std::{cell::RefMut, ops::Deref};
+//!
+use std::ops::Deref;
 
 use git_hash::{oid, ObjectId};
 
@@ -8,18 +8,25 @@ use crate::{
     easy::{ext::ObjectAccessExt, object::find, ObjectRef, Oid},
 };
 
+/// An [object id][ObjectId] infused with `Easy`.
 impl<'repo, A> Oid<'repo, A>
 where
     A: easy::Access + Sized,
 {
-    // NOTE: Can't access other object data that is attached to the same cache.
-    /// Find the [`ObjectRef`] associated with this object id, and assume it exists.
+    /// Find the [`ObjectRef`] associated with this object id, and consider it an error if it doesn't exist.
+    ///
+    /// # Note
+    ///
+    /// There can only be one `ObjectRef` per `Easy`. To increase that limit, clone the `Easy`.
     pub fn object(&self) -> Result<ObjectRef<'repo, A>, find::existing::Error> {
         self.access.find_object(self.inner)
     }
 
-    // NOTE: Can't access other object data that is attached to the same cache.
-    /// Try find the [`ObjectRef`] associated with this object id, it might not be available locally.
+    /// Try to find the [`ObjectRef`] associated with this object id, and return `None` if it's not available locally.
+    ///
+    /// # Note
+    ///
+    /// There can only be one `ObjectRef` per `Easy`. To increase that limit, clone the `Easy`.
     pub fn try_object(&self) -> Result<Option<ObjectRef<'repo, A>>, find::Error> {
         self.access.try_find_object(self.inner)
     }
@@ -50,16 +57,17 @@ where
     }
 }
 
+/// A platform to traverse commit ancestors, also referred to as commit history.
 pub struct Ancestors<'repo, A>
 where
     A: easy::Access + Sized,
 {
     repo: A::RepoRef,
-    pack_cache: RefMut<'repo, easy::PackCache>,
     access: &'repo A,
-    tip: ObjectId,
+    tips: Box<dyn Iterator<Item = ObjectId>>,
 }
 
+///
 pub mod ancestors {
     use std::ops::{Deref, DerefMut};
 
@@ -74,50 +82,76 @@ pub mod ancestors {
     where
         A: easy::Access + Sized,
     {
+        /// Obtain a platform for traversing ancestors of this commit.
         pub fn ancestors(&self) -> Result<Ancestors<'repo, A>, Error> {
-            let pack_cache = self.access.state().try_borrow_mut_pack_cache()?;
             let repo = self.access.repo()?;
             Ok(Ancestors {
-                pack_cache,
                 repo,
                 access: self.access,
-                tip: self.inner,
+                tips: Box::new(Some(self.inner).into_iter()),
             })
         }
     }
 
-    pub struct Iter<'a, 'repo, A>
-    where
-        A: easy::Access + Sized,
-    {
-        access: &'repo A,
-        inner: Box<dyn Iterator<Item = Result<git_hash::ObjectId, git_traverse::commit::ancestors::Error>> + 'a>,
-    }
-
     impl<'repo, A> Ancestors<'repo, A>
     where
         A: easy::Access + Sized,
     {
+        /// Return an iterator to traverse all commits in the history of the commit the parent [Oid] is pointing to.
         pub fn all(&mut self) -> Iter<'_, 'repo, A> {
+            let tips = std::mem::replace(&mut self.tips, Box::new(None.into_iter()));
             Iter {
                 access: self.access,
                 inner: Box::new(git_traverse::commit::Ancestors::new(
-                    Some(self.tip),
+                    tips,
                     git_traverse::commit::ancestors::State::default(),
                     move |oid, buf| {
-                        self.repo
+                        let state = self.access.state();
+                        let mut object_cache = state.try_borrow_mut_object_cache().ok()?;
+                        if let Some(c) = object_cache.deref_mut() {
+                            if let Some(kind) = c.get(&oid.to_owned(), buf) {
+                                return git_pack::data::Object::new(kind, buf).try_into_commit_iter();
+                            }
+                        }
+                        match self
+                            .repo
                             .deref()
                             .odb
-                            .try_find(oid, buf, self.pack_cache.deref_mut())
+                            .try_find(
+                                oid,
+                                buf,
+                                state
+                                    .try_borrow_mut_pack_cache()
+                                    .expect("BUG: pack cache is already borrowed")
+                                    .deref_mut(),
+                            )
                             .ok()
                             .flatten()
                             .and_then(|obj| obj.try_into_commit_iter())
+                        {
+                            Some(_) => {
+                                if let Some(c) = object_cache.deref_mut() {
+                                    c.put(oid.to_owned(), git_object::Kind::Commit, buf);
+                                }
+                                Some(git_object::CommitRefIter::from_bytes(buf))
+                            }
+                            None => None,
+                        }
                     },
                 )),
             }
         }
     }
 
+    /// The iterator returned by [`Ancestors::all()`].
+    pub struct Iter<'a, 'repo, A>
+    where
+        A: easy::Access + Sized,
+    {
+        access: &'repo A,
+        inner: Box<dyn Iterator<Item = Result<git_hash::ObjectId, git_traverse::commit::ancestors::Error>> + 'a>,
+    }
+
     impl<'a, 'repo, A> Iterator for Iter<'a, 'repo, A>
     where
         A: easy::Access + Sized,
@@ -132,7 +166,9 @@ pub mod ancestors {
     mod error {
         use crate::easy;
 
+        /// The error returned by [`Oid::ancestors()`][super::Oid::ancestors()].
         #[derive(Debug, thiserror::Error)]
+        #[allow(missing_docs)]
         pub enum Error {
             #[error(transparent)]
             BorrowRepo(#[from] easy::borrow::repo::Error),
@@ -140,7 +176,8 @@ pub mod ancestors {
             BorrowBufMut(#[from] easy::borrow::state::Error),
         }
     }
-    use error::Error;
+    pub use error::Error;
+    use git_pack::cache::Object;
 
     use crate::ext::ObjectIdExt;
 }
