@@ -1,27 +1,29 @@
-#![allow(missing_docs)]
 use git_hash::ObjectId;
-use git_traverse::commit::ancestors::{Ancestors, State};
+use git_traverse::commit::{ancestors, Ancestors};
 
 use crate::easy;
 
 pub trait Sealed {}
 
+/// An extension trait to add functionality to [`ObjectId`]s.
 pub trait ObjectIdExt: Sealed {
-    fn ancestors_iter<Find>(self, find: Find) -> Ancestors<Find, fn(&git_hash::oid) -> bool, State>
+    /// Create an iterator over the ancestry of the commits reachable from this id, which must be a commit.
+    fn ancestors<Find>(self, find: Find) -> Ancestors<Find, fn(&git_hash::oid) -> bool, ancestors::State>
     where
         Find: for<'a> FnMut(&git_hash::oid, &'a mut Vec<u8>) -> Option<git_object::CommitRefIter<'a>>;
 
+    /// Infuse this object id with an [`easy::Access`].
     fn attach<A: easy::Access + Sized>(self, access: &A) -> easy::Oid<'_, A>;
 }
 
 impl Sealed for ObjectId {}
 
 impl ObjectIdExt for ObjectId {
-    fn ancestors_iter<Find>(self, find: Find) -> Ancestors<Find, fn(&git_hash::oid) -> bool, State>
+    fn ancestors<Find>(self, find: Find) -> Ancestors<Find, fn(&git_hash::oid) -> bool, ancestors::State>
     where
         Find: for<'a> FnMut(&git_hash::oid, &'a mut Vec<u8>) -> Option<git_object::CommitRefIter<'a>>,
     {
-        Ancestors::new(Some(self), State::default(), find)
+        Ancestors::new(Some(self), ancestors::State::default(), find)
     }
 
     fn attach<A: easy::Access + Sized>(self, access: &A) -> easy::Oid<'_, A> {
